@@ -4,7 +4,7 @@ from io import open
 from itertools import chain
 import os.path
 import logging
-from typing import Optional, List, Dict, Iterable
+from typing import Optional, List, Dict, Iterable, Any
 
 from .common import IntOrFloat
 from .formats import autodetect_format, get_format_class, get_format_identifier
@@ -43,6 +43,7 @@ class SSAFile(MutableSequence):
         self.styles: Dict[str, SSAStyle] = {"Default": SSAStyle.DEFAULT_STYLE.copy()}  #: Dict of :class:`SSAStyle` instances.
         self.info: Dict[str, str] = self.DEFAULT_INFO.copy()  #: Dict with script metadata, ie. ``[Script Info]``.
         self.aegisub_project: Dict[str, str] = {}  #: Dict with Aegisub project, ie. ``[Aegisub Project Garbage]``.
+        self.fonts_opaque: Dict[str, Any] = {}  #: Dict with embedded fonts, ie. ``[Fonts]``.
         self.fps: Optional[float] = None  #: Framerate used when reading the file, if applicable.
         self.format: Optional[str] = None  #: Format of source subtitle file, if applicable, eg. ``"srt"``.
 
@@ -55,6 +56,13 @@ class SSAFile(MutableSequence):
         """
         Load subtitle file from given path.
 
+        This method is implemented in terms of :meth:`SSAFile.from_file()`.
+
+        See also:
+            Specific formats may implement additional loading options,
+            please refer to documentation of the implementation classes
+            (eg. :meth:`pysubs2.subrip.SubripFormat.from_file()`)
+
         Arguments:
             path (str): Path to subtitle file.
             encoding (str): Character encoding of input file.
@@ -68,14 +76,7 @@ class SSAFile(MutableSequence):
                 be detected from the file, in which case you don't need
                 to specify it here (when given, this argument overrides
                 autodetection).
-            keep_unknown_html_tags (bool): This affects SubRip only (SRT),
-                for other formats this argument is ignored.
-                By default, HTML tags are converted to equivalent SubStation tags
-                (eg. ``<i>`` to ``{\\i1}`` and any remaining tags are removed
-                to keep the text clean. Set this parameter to ``True``
-                if you want to pass through these tags (eg. ``<sub>``).
-                This is useful if your output format is SRT and your player
-                supports these tags.
+            kwargs: Extra options for the reader.
 
         Returns:
             SSAFile
@@ -166,6 +167,13 @@ class SSAFile(MutableSequence):
         """
         Save subtitle file to given path.
 
+        This method is implemented in terms of :meth:`SSAFile.to_file()`.
+
+        See also:
+            Specific formats may implement additional saving options,
+            please refer to documentation of the implementation classes
+            (eg. :meth:`pysubs2.subrip.SubripFormat.to_file()`)
+
         Arguments:
             path (str): Path to subtitle file.
             encoding (str): Character encoding of output file.
@@ -392,6 +400,18 @@ class SSAFile(MutableSequence):
                     logging.debug("info %r differs (self=%r, other=%r)", key, sv, ov)
                     return False
 
+            for key in set(chain(self.fonts_opaque.keys(), other.fonts_opaque.keys())):
+                sv, ov = self.fonts_opaque.get(key), other.fonts_opaque.get(key)
+                if sv is None:
+                    logging.debug("%r missing in self.fonts_opaque", key)
+                    return False
+                elif ov is None:
+                    logging.debug("%r missing in other.fonts_opaque", key)
+                    return False
+                elif sv != ov:
+                    logging.debug("fonts_opaque %r differs (self=%r, other=%r)", key, sv, ov)
+                    return False
+
             for key in set(chain(self.styles.keys(), other.styles.keys())):
                 sv, ov = self.styles.get(key), other.styles.get(key)
                 if sv is None:
