@@ -1,3 +1,4 @@
+import logging
 import re
 from numbers import Number
 from .formatbase import FormatBase
@@ -14,7 +15,14 @@ def ass_to_ssa_alignment(i):
 def ssa_to_ass_alignment(i):
     return SSA_ALIGNMENT.index(i) + 1
 
-SECTION_HEADING = re.compile(r"^.{,3}\[[^\]]+\]") # allow for UTF-8 BOM, which is 3 bytes
+SECTION_HEADING = re.compile(
+    r"^.{,3}"  # allow 3 chars at start of line for BOM
+    r"\["  # open square bracket
+    r"[^]]*[a-z][^]]*"  # inside square brackets, at least one lowercase letter (this guards vs. uuencoded font data)
+    r"]"  # close square bracket
+)
+
+FONT_FILE_HEADING = re.compile(r"fontname:\s+(\S+)")
 
 STYLE_FORMAT_LINE = {
     "ass": "Format: Name, Fontname, Fontsize, PrimaryColour, SecondaryColour, OutlineColour, BackColour, Bold, Italic,"
@@ -45,7 +53,7 @@ EVENT_FIELDS = {
 #: Largest timestamp allowed in SubStation, ie. 9:59:59.99.
 MAX_REPRESENTABLE_TIME = make_time(h=10) - 10
 
-def ms_to_timestamp(ms):
+def ms_to_timestamp(ms: int) -> str:
     """Convert ms to 'H:MM:SS.cc'"""
     # XXX throw on overflow/underflow?
     if ms < 0: ms = 0
@@ -53,13 +61,13 @@ def ms_to_timestamp(ms):
     h, m, s, ms = ms_to_times(ms)
     return "%01d:%02d:%02d.%02d" % (h, m, s, ms//10)
 
-def color_to_ass_rgba(c):
+def color_to_ass_rgba(c: Color) -> str:
     return "&H%08X" % ((c.a << 24) | (c.b << 16) | (c.g << 8) | c.r)
 
-def color_to_ssa_rgb(c):
+def color_to_ssa_rgb(c: Color) -> str:
     return "%d" % ((c.b << 16) | (c.g << 8) | c.r)
 
-def rgba_to_color(s):
+def rgba_to_color(s: str) -> Color:
     if s[0] == '&':
         x = int(s[2:], base=16)
     else:
@@ -70,7 +78,7 @@ def rgba_to_color(s):
     a = (x >> 24) & 0xff
     return Color(r, g, b, a)
 
-def is_valid_field_content(s):
+def is_valid_field_content(s: str) -> bool:
     """
     Returns True if string s can be stored in a SubStation field.
 
@@ -135,8 +143,10 @@ def parse_tags(text, style=SSAStyle.DEFAULT_STYLE, styles={}):
 NOTICE = "Script generated by pysubs2\nhttps://pypi.python.org/pypi/pysubs2"
 
 class SubstationFormat(FormatBase):
+    """SubStation Alpha (ASS, SSA) subtitle format implementation"""
     @classmethod
     def guess_format(cls, text):
+        """See :meth:`pysubs2.formats.FormatBase.guess_format()`"""
         if "V4+ Styles" in text:
             return "ass"
         elif "V4 Styles" in text:
@@ -144,6 +154,7 @@ class SubstationFormat(FormatBase):
 
     @classmethod
     def from_file(cls, subs, fp, format_, **kwargs):
+        """See :meth:`pysubs2.formats.FormatBase.from_file()`"""
 
         def string_to_field(f, v):
             if f in {"start", "end"}:
@@ -175,16 +186,22 @@ class SubstationFormat(FormatBase):
         subs.info.clear()
         subs.aegisub_project.clear()
         subs.styles.clear()
+        subs.fonts_opaque.clear()
 
         inside_info_section = False
         inside_aegisub_section = False
+        inside_font_section = False
+        current_font_name = None
+        current_font_lines_buffer = []
 
-        for line in fp:
+        for lineno, line in enumerate(fp, 1):
             line = line.strip()
 
             if SECTION_HEADING.match(line):
+                logging.debug("at line %d: section heading %s", lineno, line)
                 inside_info_section = "Info" in line
                 inside_aegisub_section = "Aegisub" in line
+                inside_font_section = "Fonts" in line
             elif inside_info_section or inside_aegisub_section:
                 if line.startswith(";"): continue # skip comments
                 try:
@@ -195,6 +212,24 @@ class SubstationFormat(FormatBase):
                         subs.aegisub_project[k] = v.strip()
                 except ValueError:
                     pass
+            elif inside_font_section:
+                m = FONT_FILE_HEADING.match(line)
+
+                if current_font_name and (m or not line):
+                    # flush last font on newline or new font name
+                    font_data = current_font_lines_buffer[:]
+                    subs.fonts_opaque[current_font_name] = font_data
+                    logging.debug("at line %d: finished font definition %s", lineno, current_font_name)
+                    current_font_lines_buffer.clear()
+                    current_font_name = None
+
+                if m:
+                    # start new font
+                    font_name = m.group(1)
+                    current_font_name = font_name
+                elif line:
+                    # add non-empty line to current buffer
+                    current_font_lines_buffer.append(line)
             elif line.startswith("Style:"):
                 _, rest = line.split(":", 1)
                 buf = rest.strip().split(",")
@@ -210,9 +245,18 @@ class SubstationFormat(FormatBase):
                 ev = SSAEvent(**field_dict)
                 subs.events.append(ev)
 
+        # cleanup fonts
+        if current_font_name:
+            # flush last font on EOF or new section w/o newline
+            font_data = current_font_lines_buffer[:]
+            subs.fonts_opaque[current_font_name] = font_data
+            logging.debug("at EOF: finished font definition %s", current_font_name)
+            current_font_lines_buffer.clear()
+            current_font_name = None
 
     @classmethod
     def to_file(cls, subs, fp, format_, header_notice=NOTICE, **kwargs):
+        """See :meth:`pysubs2.formats.FormatBase.to_file()`"""
         print("[Script Info]", file=fp)
         for line in header_notice.splitlines(False):
             print(";", line, file=fp)
@@ -251,6 +295,14 @@ class SubstationFormat(FormatBase):
             fields = [field_to_string(f, getattr(sty, f), sty) for f in STYLE_FIELDS[format_]]
             print("Style: %s" % name, *fields, sep=",", file=fp)
 
+        if subs.fonts_opaque:
+            print("\n[Fonts]", file=fp)
+            for font_name, font_lines in sorted(subs.fonts_opaque.items()):
+                print("fontname: {}".format(font_name), file=fp)
+                for line in font_lines:
+                    print(line, file=fp)
+                print(file=fp)
+
         print("\n[Events]", file=fp)
         print(EVENT_FORMAT_LINE[format_], file=fp)
         for ev in subs.events:
